<?php

namespace Drupal\entityreference_modal_create\Controller;

use Drupal\Core\Access\AccessResult;
use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Session\AccountInterface;

/**
 * Returns responses for Referenced entity modal routes.
 */
class ReferencedEntityModalController extends ControllerBase {

  /**
   * Builds the response.
   */
  public function build($entityType,$bundle,$mode,$selector) {
    \Drupal::service('page_cache_kill_switch')->trigger();
    $bundleKey = \Drupal::entityTypeManager()->getDefinition($entityType)->getKey('bundle');
    $entity = \Drupal::service("entity_type.manager")->getStorage($entityType)->create([
      $bundleKey => $bundle,
    ]);
    $form = \Drupal::service('entity.form_builder')->getForm($entity, $mode);
    $form['#cache']['max-age'] = 0;
    return $form;
  }

  /**
   * Checks access for a specific request.
   *
   * @param \Drupal\Core\Session\AccountInterface $account
   *   Run access checks for this account.
   *
   * @return \Drupal\Core\Access\AccessResultInterface
   *   The access result.
   */
  public function access(AccountInterface $account,$entityType,$bundle,$mode,$selector) {
    $entity_manager = \Drupal::entityTypeManager();
    $wrapper_format = \Drupal::request()->get('_wrapper_format');
    $drupal_ajax = \Drupal::request()->get('_drupal_ajax');
    if($wrapper_format != 'drupal_modal' && $drupal_ajax != 1){
      return AccessResult::forbidden();
    }
    if(\Drupal::request()->getSession()->get($selector) == 'bypassed'){
      return AccessResult::allowed();
    }
    $access_handler = $entity_manager->getAccessControlHandler($entityType);
    $access = FALSE;
    if ($bundle) {
      $access = $access_handler->createAccess($bundle);
    }
    else {
      $access = $access_handler->createAccess();
    }
    return AccessResult::allowedIf($access);
  }


}
